// 12F675
//                     ---------
//                  5V |1    18| 0V
//          8MHz-->GP5 |2    17| GP0--> buzzer
//             /<--GP4 |3    16| GP1<-- Monitor
//             /<--GP3 |4    15| GP2--> FET gate
//                     --------- 
//
// winker relay


//#include "12F675.h

/*
bit 13-12	11 Highest bandgap voltage
bit 8	1 Data memory code portection is desabled
bit 7	1 Program Memory code protection is disabled
bit 6	1 BOD enable	
bit 5	0 GP3/MCLRn pin function is digital I/O
bit 4	0 PWRT(Power-up Timer Enable bit) enable
bit 3	1 WDT enable
bit 210	011 External input on OSC1 GP5 (2pin)

//bit 210	100 INTOSC I/O on GP4
*/

//#pragma config  = 0x3F84
#pragma config  = 0x3FCB

//------------------------------------------------

/***********/
/* DEFINES */
/***********/

#define TRUE                    1
#define FALSE                   0
#define	HIGH					1
#define LOW						0
#define ON						1
#define OFF						0


//-----------------------------------------------
#pragma bit OP_0 @ GPIO.0
#pragma bit OP_1 @ GPIO.1
#pragma bit OP_2 @ GPIO.2
#pragma bit OP_3 @ GPIO.3
#pragma bit OP_4 @ GPIO.4
#pragma bit OP_5 @ GPIO.5

//-----------------------------------------------
#pragma bit FET @ OP_2
#pragma bit BUZZER @ OP_0
#pragma bit MONITOR @ OP_1


#include "int16CXX.h"  // device dependent interrupt definitions
//-----------------------------------------------
#pragma origin 4
interrupt serverX( void)
{
    int_save_registers    // W, STATUS (and PCLATH if required)

    //char sv_FSR = FSR;  // save FSR when using tables/pointers
    /* An error is generated if FSR need to be saved and the compiler
       does not detect that this is actually done */

    // handle the interrupt
    if ( GPIF==1 ){
    	GPIF=0;			// INT flat reset
    }

	if( MONITOR==LOW ){
		GPIF=0;
	}
	

    //FSR = sv_FSR;               // restore FSR if saved
    int_restore_registers // W, STATUS (and PCLATH if required)
}
// GIE is automatically set to 1 on exit (by RETFIE).

//-----------------------------------------------
void delay_ms( uns16 millisec)
// Delays a multiple of 1 milliseconds at 4 MHz
// using the TMR0 timer
{
    char next = 0;

//    OPTION = 2; // prescaler divide TMR0 rate by 8
    OPTION = 3; // prescaler divide TMR0 rate by 16
    TMR0 = 2;  // deduct 2*8 fixed instruction cycles delay
    do  {
        next += 125;
        clrwdt();  // needed only if watchdog is enabled
        while (TMR0 != next)   // 125 * 8 = 1000 (= 1 ms)
            ;
    } while ( -- millisec != 0);
}

//-----------------------------------------------
//--------------------------------------------------------------------
void main( void)
{
	unsigned int	i;
	unsigned int	j;

	OSCCAL = W;
 	GPIO = 0;
 	TRISIO = 0x02;		//GPIO 1=input  GPIO 0,2,3,4=output
	CMCON = 0x07;		//CM2,1,0=HIGH : scomparators are OFF
	ANSEL = 0;			//digital IO
 	OPTION = 0x0F;		// /GPPU=LOW, WDT prescaler 1/128
 	TMR0 = 0;
//	T1CON = 0x01;	// b5:4 00=1:1prescale  b1 enables timer1 ->1MHz clock
	INTCON = 0x88;	// GIE INTE
	IOCB = 0x02;		// IOC1
//	WPU = 0x02;			// GPIO1 weak pull up


	OP_0=LOW;
	OP_2=LOW;
	OP_3=LOW;
	OP_4=LOW;



	// buzzer pi pi 
	for( i=0 ; i<50 ; i++){
		BUZZER=ON;
		for(j=0 ; j<80 ; j++);
		BUZZER=OFF;
		for(j=0 ; j<80 ; j++);
	}
	for( i=0 ; i<50 ; i++){
		for(j=0 ; j<130 ; j++);
	}
	for( i=0 ; i<50 ; i++){
		BUZZER=ON;
		for(j=0 ; j<80 ; j++);
		BUZZER=OFF;
		for(j=0 ; j<80 ; j++);
	}
	
//-----------------------------------------start of while
while(TRUE){

	// if winker switch is off (MONITOR==HIGH), then sleep
	if( MONITOR==HIGH ){
		do{
		 	OPTION = 0x0F;		//WDT prescaler 1/128
			sleep();
			clrwdt();	// watch dog clear
		}
		while ( MONITOR==HIGH );
	}

	// FET ON = LED ON
	FET=ON;

	// buzzer pi
	for( i=0 ; i<80 ; i++){
		BUZZER=ON;
		for(j=0 ; j<100 ; j++);
		BUZZER=OFF;
		for(j=0 ; j<100 ; j++);
	}

	// watch dog clear
	clrwdt();

	// 200msec wait
	delay_ms(330);
 	OPTION = 0x0F;		//WDT prescaler 1/128

	// FET OFF = LED OFF
	FET=OFF;

	// wait 300msec
	delay_ms(400);
 	OPTION = 0x0F;		//WDT prescaler 1/128

	// watch dog clear
	clrwdt();

}  // end of while


}	// end of main
